@@ -1,10 +1,13 @@
 from koil.qt import FutureWrapper
-from mikro.schema import Representation, RepresentationVariety
+from mikro.schema import Representation, RepresentationVariety, Table
 from napari import Viewer
 import xarray as xr
 from qtpy import QtWidgets
 from qtpy.QtCore import Signal, QObject
 import logging
+from mikro import gql
+import pandas as pd
+import numpy as np
 
 logger = logging.getLogger(__name__)
 
@@ -20,6 +23,7 @@ class DownloadIndicator(QtWidgets.QWidget):
 
 class StageHelper(QObject):
     openStack = Signal(xr.DataArray, Representation)
+    openPoints = Signal(np.ndarray, str)
     openLabels = Signal(xr.DataArray, Representation)
     openImage = Signal(xr.DataArray, Representation)
     downloadingImage = Signal(Representation)
@@ -33,6 +37,7 @@ class StageHelper(QObject):
 
         self.openImage.connect(self.open_xarray_as_rgb)
         self.openStack.connect(self.open_xarray_as_stack)
+        self.openPoints.connect(self.open_array_as_points)
         self.openLabels.connect(self.open_xarray_as_labels)
 
         self.downloadingImage.connect(self.on_image_download)
@@ -51,7 +56,13 @@ class StageHelper(QObject):
             rgb=False,
             name=rep.name,
             metadata={"rep": rep},
-        )  # why this werid transposing... hate napari
+        )
+
+    def open_array_as_points(self, array: np.ndarray, name="Points"):
+        self.viewer.add_points(
+            array,
+            name=name,
+        )
 
     def open_xarray_as_rgb(self, array: xr.DataArray, rep: Representation):
         self.viewer.add_image(
@@ -139,6 +150,38 @@ class StageHelper(QObject):
                 f"Cannot open Representation of Variety {rep.variety}"
             )
 
+    def open_with_localizations(self, rep: Representation):
+
+        query = gql(
+            """
+            query Representation($id: ID!){
+                representation(id: $id){
+                    store
+                    name
+                    tables(tags: ["localization"]) {
+                        id
+                        store
+                    }
+                }
+            }
+            """
+        ).run(id=rep.id)
+
+        rep = query.representation
+        localizations = rep.tables[0].data
+        localizations = localizations[
+            [
+                "Plane",
+                "CentroidY(px)",
+                "CentroidX(px)",
+            ]
+        ]
+        locs = localizations.to_numpy()
+        print(locs.shape)
+
+        self.openStack.emit(rep.data.compute(), rep)
+        self.openPoints.emit(locs, "localizations")
+
     def get_active_layer_as_xarray(self):
         layer = self.viewer.active_layer
         data = layer.data
